==> jenova-0.5.1.tar.gz: jenova-0.5.1/src/client.h <==
/* $Id: client.h,v 1.25 2001/08/10 02:56:32 robey Exp $
 *
 * Copyright (C) 2000, 2001  Robey Pointer <robey@lag.net>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2, or (at your option) any
 * later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef _CLIENT_H_
#define _CLIENT_H_

#include <say2/say2.h>

typedef enum {
        CLIENT_MODE_ACTIVE = 0,
        CLIENT_MODE_IDLE,		/* not really used, but sometimes returned */
        CLIENT_MODE_AWAY,
        CLIENT_MODE_BUSY
} ClientMode;

/* flags */
typedef enum {
        CLIENT_USER	= (1<<0),
        CLIENT_CHANNEL  = (1<<1),
        CLIENT_NOTIFY   = (1<<2),
        CLIENT_OFFLINE  = (1<<3),
        CLIENT_GUEST	= (1<<4),	/* not a registered user */
} ClientFlags;

/* privs */
typedef enum {
        PRIV_ADDUSER	= (1<<0),	/* A */
        PRIV_BOOTUSER	= (1<<1),	/* B */
        PRIV_DEBUG	= (1<<2),	/* D */
        PRIV_WALL	= (1<<3),	/* W */
} ClientPrivs;

/* there needs to be some sort of arbitrary limit or people will abuse it */
/* (if you set this larger than 32, you'll have to hack something up for the ping_flags below) */
#define CLIENT_MAX_SOCKETS	8

typedef struct {
	Socket *	socket;
	char *		host;
	guint16		port;
	gboolean	ping_pending;
        char *		version;	/* client identifier string */
} ClientConnection;

typedef struct {
        gint32		magic;
	GList *		conn_list;	/* ClientConnection */
        char *		id;
        ClientFlags	flags;
        ClientPrivs	privs;
        char *		nick;
        char *		email;
        char *		tagline;
        char *		status;		/* usually away or busy message */
        char *		address;	/* host:port for remote connections */
        char *		icon;
        int		iconsize;
        time_t		login;
        time_t		activity;
        time_t		status_changed;
        ClientMode	mode;
        GList *		buddy_list;	/* (not saved) not defined yet */
        GList *		block_list;
        EnamlBlock *	attributes;
} Client;


#define CLIENT_MAGIC	0xC71E27F9

#define IS_CLIENT(x)	((x)->magic == CLIENT_MAGIC)


Client *client_new (Socket *sock, const char *host, guint16 port);
void client_free (Client *client);
int client_count (void);
gboolean client_move_socket (Client *client, Client *from_client, const Socket *sock);
gboolean client_remove_socket (Client *client, const Socket *sock);
void client_close_all_sockets_but (Client *client, const Socket *sock);
void client_close_all_sockets (Client *client);
gboolean client_has_sockets (Client *client);
const char *client_host_by_socket (Client *client, const Socket *sock);
const char *client_get_version (const Client *client);
void client_set_version (Client *client, char *version);
Client *client_by_nick (const char *nick);
Client *client_by_id (const char *id, ClientFlags flags);
GList *client_grep (const char *grep);
void client_get_list (EnamlBlock *block, const char *key, const char *grep, ClientFlags flags);
void client_get_id_list (EnamlBlock *block, const char *key, const char *grep, ClientFlags flags);
void client_notify_signon (Client *client);
void client_notify_signoff (Client *client);
void client_send (const Client *client, const EnamlBlock *block);
void client_sendf (Client *client, const char *tag, const char *fmt, ...);
void client_broadcast (const EnamlBlock *block);
void client_got_ping (Client *client, Socket *sock);
void client_ping_all (void);
Client *client_get_target (const EnamlBlock *block, ClientFlags flags, EnamlBlock **error_block);
const char *client_mode_string (const Client *client);
char *client_privs_to_string (const Client *client);
char *client_prefs_to_string (const Client *client);
void client_string_to_privs (Client *client, const char *str);
void client_string_to_prefs (Client *client, const char *str);
int client_type_to_flags (const char *type);
char *client_to_string (Client *client, gboolean verbose);

#endif	/* _CLIENT_H_ */

==> jenova-0.6.1.tar.gz: jenova-0.6.1/src/client.h <==
/* $Id: client.h,v 1.32 2001/11/04 01:07:03 robey Exp $
 *
 * Copyright (C) 2000, 2001  Robey Pointer <robey@lag.net>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2, or (at your option) any
 * later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef _CLIENT_H_
#define _CLIENT_H_

#include <say2/say2.h>

typedef enum {
        CLIENT_MODE_ACTIVE = 0,
        CLIENT_MODE_IDLE,		/* not really used, but sometimes returned */
        CLIENT_MODE_AWAY,
        CLIENT_MODE_BUSY
} ClientMode;

/* flags */
typedef enum {
        CLIENT_USER	= (1<<0),
        CLIENT_CHANNEL  = (1<<1),
        CLIENT_NOTIFY   = (1<<2),
        CLIENT_NO_MSG	= (1<<3),	/* not receiving incoming msgs */
        CLIENT_OFFLINE  = (1<<14),
        CLIENT_GUEST	= (1<<15),	/* not a registered user */
} ClientFlags;

/* privs */
typedef enum {
        PRIV_ADDUSER	= (1<<0),	/* A */
        PRIV_BOOTUSER	= (1<<1),	/* B */
        PRIV_DEBUG	= (1<<2),	/* D */
        PRIV_WALL	= (1<<3),	/* W */
} ClientPrivs;

typedef enum {
        BUDDY_APPROVED 	= (1<<0),
        BUDDY_BLOCKED	= (1<<1),
        BUDDY_DENIED	= (1<<2),
        BUDDY_STORED	= (1<<3),	/* approved/denied, storing message until the target signs on */
} BuddyFlags;

/* there needs to be some sort of arbitrary limit or people will abuse it */
/* (if you set this larger than 32, you'll have to hack something up for the ping_flags below) */
#define CLIENT_MAX_SOCKETS	8

typedef struct {
	Socket *	socket;
	char *		host;
	guint16		port;
	gboolean	ping_pending;
        char *		version;	/* client identifier string */
} ClientConnection;

/* maximum times your buddy request can be denied before it will stop trying */
#define CLIENT_MAX_BUDDY_DENIALS	5

/* maximum length of buddy message sent on a subscription request */
#define CLIENT_MAX_BUDDY_MESSAGE	80

typedef struct {
        char *		id;
        BuddyFlags	flags;
        int		deny_count;
        char *		message;	/* only for reverse-buddy */
} Buddy;

/* proxy auth for channels */
typedef struct {
        char *		key;
        char *		channel;
} ClientAuth;

typedef struct {
        gint32		magic;
	GList *		conn_list;	/* ClientConnection */
        char *		id;
        ClientFlags	flags;
        ClientPrivs	privs;
        char *		nick;
        char *		email;
        char *		tagline;
        char *		status;		/* usually away or busy message */
        char *		address;	/* host:port for remote connections */
        char *		icon;
        int		iconsize;
        time_t		login;
        time_t		activity;
        time_t		status_changed;
        ClientMode	mode;
        GList *		buddy_list;		/* GList<Buddy *> */
        GList *		reverse_buddy_list;	/* GList<Buddy *>   people subscribed to me */
        GList *		auth_list;		/* GList<ClientAuth *> */
        EnamlBlock *	attributes;
} Client;


#define CLIENT_MAGIC	0xC71E27F9

#define IS_CLIENT(x)	((x)->magic == CLIENT_MAGIC)


Client *client_new (gboolean add_to_roster);
void client_new_connection(Client *client, Socket *sock, const char *host, guint16 port);
void client_free (Client *client);
void client_discard (Client *client);
Buddy *client_buddy_add (Client *client, const char *id, BuddyFlags flags, const char *message,
                         int deny_count);
Buddy *client_buddy_find (Client *client, const char *id);
gboolean client_buddy_remove (Client *client, const char *id);
Buddy *client_buddy_add_reverse (Client *client, const char *id, BuddyFlags flags, const char *message);
Buddy *client_buddy_find_reverse (Client *client, const char *id);
gboolean client_buddy_remove_reverse (Client *client, const char *id);
void client_show_buddy_status (Client *client);
int client_count (void);
gboolean client_move_socket (Client *client, Client *from_client, const Socket *sock);
gboolean client_remove_socket (Client *client, const Socket *sock);
void client_close_all_sockets_but (Client *client, const Socket *sock);
void client_close_all_sockets (Client *client);
gboolean client_has_sockets (Client *client);
const char *client_host_by_socket (Client *client, const Socket *sock);
const char *client_get_version (const Client *client);
void client_set_version (Client *client, char *version);
Client *client_by_nick (const char *nick);
Client *client_by_id (const char *id, ClientFlags flags);
GList *client_grep (const char *grep);
void client_get_list (EnamlBlock *block, const char *key, const char *grep, ClientFlags flags);
void client_get_id_list (EnamlBlock *block, const char *key, const char *grep, ClientFlags flags);
void client_notify_signon (Client *client);
void client_notify_signoff (Client *client);
void client_send_text (const Client *client, const char *text);
void client_send (const Client *client, const EnamlBlock *block);
void client_sendf (const Client *client, const char *tag, const char *fmt, ...);
void client_broadcast (const EnamlBlock *block);
void client_got_ping (Client *client, Socket *sock);
void client_ping_all (void);
Client *client_lookup_offline (void *db_state, const char *id, int flags);
Client *client_get_target (const EnamlBlock *block, ClientFlags flags, EnamlBlock **error_block);
Client *client_get_offline_target (void *db_state, const EnamlBlock *block, ClientFlags flags,
				   EnamlBlock **error_block);
const char *client_mode_string (const Client *client);
EnamlBlock *client_make_status (const Client *client, gboolean online);
char *client_privs_to_string (const Client *client);
char *client_prefs_to_string (const Client *client);
void client_string_to_privs (Client *client, const char *str);
void client_string_to_prefs (Client *client, const char *str);
int client_type_to_flags (const char *type);
char *client_to_string (Client *client, gboolean verbose);

#endif	/* _CLIENT_H_ */
